﻿using System;
using Windows.ApplicationModel.DataTransfer;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace ClipboardDemo.Areas
{
    public sealed partial class CopyFileArea : UserControl
    {
        public CopyFileArea()
        {
            this.InitializeComponent();
        }

        private async void copyButton_Click(object sender, RoutedEventArgs e)
        {
            Clipboard.Clear();
            this.destinationTextBox.Text = "";
            var filePicker = new FileOpenPicker
            {
                ViewMode = PickerViewMode.List,
                FileTypeFilter = { "*" }
            };
            var storageItems = await filePicker.PickMultipleFilesAsync();
            if (storageItems.Count > 0)
            {
                var datapackage = new DataPackage();
                datapackage.SetStorageItems(storageItems);

                // Kopieroperation von der Quelle anfordern
                datapackage.RequestedOperation = DataPackageOperation.Copy;
                Clipboard.SetContent(datapackage);
                this.destinationTextBox.Text += storageItems.Count + " Datei(en) in die Zwischenablage kopiert.";
            }
            else
            {
                this.destinationTextBox.Text += "(keine Datei ausgewählt)";
            }
        }

        private async void pasteButton_Click(object sender, RoutedEventArgs e)
        {
            var displayString = string.Empty;
            var dataPackageView = Clipboard.GetContent();
            if (dataPackageView.Contains(StandardDataFormats.StorageItems))
            {
                var storageItems = await dataPackageView.GetStorageItemsAsync();
                if (storageItems != null)
                {
                    displayString = "Kopiere " + storageItems.Count + " Datei(en) in das Verzeichnis " + ApplicationData.Current.LocalFolder.Path + Environment.NewLine;
                    displayString += "Angeforderte Operation: " + dataPackageView.RequestedOperation.ToString() + Environment.NewLine;
                    foreach (IStorageItem storageItem in storageItems)
                    {
                        if (storageItem != null)
                        {
                            if (storageItem.IsOfType(StorageItemTypes.File))
                            {
                                // Datei kopieren
                                var file = storageItem as StorageFile;
                                var copiedFile = await file.CopyAsync(ApplicationData.Current.LocalFolder, file.Name, NameCollisionOption.ReplaceExisting);
                                if (copiedFile != null)
                                {
                                    displayString += " - " + file.Path + Environment.NewLine;
                                }
                                else
                                {
                                    displayString += " - Fehler beim Kopieren der Datei " + file.Path + Environment.NewLine;
                                }
                            }
                        }
                    }
                }
            }
            this.destinationTextBox.Text = displayString;
        }

        private void clearButton_Click(object sender, RoutedEventArgs e)
        {
            Clipboard.Clear();
            this.destinationTextBox.Text = "";
        }
    }
}
