﻿using System;
using Windows.ApplicationModel.DataTransfer;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.Storage.Streams;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media.Imaging;

namespace ClipboardDemo.Areas
{
    public sealed partial class CopyImageArea : UserControl
    {
        private StorageFile _imageFile;

        public CopyImageArea()
        {
            this.InitializeComponent();
        }
        
        private async void copyButton_Click(object sender, RoutedEventArgs e)
        {
            var datapackage = new DataPackage();
            StorageFile imageFile = null;
            Clipboard.Clear();

            var imagePicker = new FileOpenPicker
            {
                ViewMode = PickerViewMode.Thumbnail,
                SuggestedStartLocation = PickerLocationId.PicturesLibrary,
                FileTypeFilter = { ".jpg", ".png", ".bmp", ".gif", ".tif" }
            };
            imageFile = await imagePicker.PickSingleFileAsync();
            if (imageFile != null)
            {
                if (this.deferedCheckBox.IsChecked.Value)
                {
                    _imageFile = imageFile;
                    datapackage.SetDataProvider(StandardDataFormats.Bitmap, this.OnDeferredImageRequestedHandler);
                }
                else
                {
                    _imageFile = null;
                    datapackage.SetBitmap(RandomAccessStreamReference.CreateFromFile(imageFile));
                }
                Clipboard.SetContent(datapackage);
            }
        }

        private async void pasteButton_Click(object sender, RoutedEventArgs e)
        {
            var dataPackageView = Clipboard.GetContent();
            if (dataPackageView == null || dataPackageView.AvailableFormats.Count == 0)
            {
                this.destinationImage.ClearValue(Image.SourceProperty);
            }
            else if (dataPackageView.Contains(StandardDataFormats.Bitmap))
            {
                var stream = await dataPackageView.GetBitmapAsync();
                var imageStream = await stream.OpenReadAsync();
                var source = new BitmapImage();
                source.SetSource(imageStream);
                this.destinationImage.Source = source;
            }
        }

        private void clearButton_Click(object sender, RoutedEventArgs e)
        {
            Clipboard.Clear();
            this.destinationImage.ClearValue(Image.SourceProperty);
        }

        private async void OnDeferredImageRequestedHandler(DataProviderRequest request)
        {
            if (_imageFile != null)
            {
                var deferral = request.GetDeferral();
                var imageStream = await _imageFile.OpenAsync(FileAccessMode.Read);
                request.SetData(RandomAccessStreamReference.CreateFromStream(imageStream));
                deferral.Complete();
                _imageFile = null;
            }
        }
    }
}
