﻿using System;
using Windows.ApplicationModel.DataTransfer;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace ClipboardDemo.Areas
{
    public sealed partial class CopyTextArea : UserControl
    {
        public CopyTextArea()
        {
            this.InitializeComponent();
        }

        private void copyButton_Click(object sender, RoutedEventArgs e)
        {
            // Eingabetext ermitteln
            var text = string.IsNullOrWhiteSpace(this.sourceTextBox.SelectedText) ? this.sourceTextBox.Text : this.sourceTextBox.SelectedText;
            
            // Text im Textformat in der Zwischenablage speichern
            var datapackage = new DataPackage();
            datapackage.SetText(text);
            
            // Text im HTML-Format in der Zwischenablage speichern
            string htmlString = HtmlFormatHelper.CreateHtmlFormat(text);
            datapackage.SetHtmlFormat(htmlString);
            
            // Text im RTF-Format in der Zwischenablage speichern
            datapackage.SetRtf("{\\rtf1\\ansi " + text + "\\line}");
            
            // Inhalt in benutzerdefiniertem Format speichern
            datapackage.SetData("MeinFormat", text);

            // Inhalt zuweisen
            Clipboard.SetContent(datapackage);
        }

        private async void pasteButton_Click(object sender, RoutedEventArgs e)
        {
            var displayString = "(kein Textformat in der Zwischenablage)";
            var dataPackageView = Clipboard.GetContent();
            if (dataPackageView == null)
                return;
            if (dataPackageView.Contains("MeinFormat"))
            {
                var result = await dataPackageView.GetDataAsync("MeinFormat");
                displayString = result.ToString();
            }
            else if (dataPackageView.Contains(StandardDataFormats.Rtf))
            {
                var result = await dataPackageView.GetDataAsync("Rich Text Format");
                displayString = result.ToString();
            }
            else if (dataPackageView.Contains(StandardDataFormats.Text))
            {
                displayString = await dataPackageView.GetTextAsync();
            }
            if (dataPackageView.Contains(StandardDataFormats.Html))
            {
                var html = await dataPackageView.GetHtmlFormatAsync();
                var htmlString = HtmlFormatHelper.GetStaticFragment(html);
                this.destinationWebView.NavigateToString(htmlString);
            }
            this.destinationTextBox.Text = displayString;
        }

        private void clearButton_Click(object sender, RoutedEventArgs e)
        {
            Clipboard.Clear();
            this.destinationTextBox.Text = "";
            this.destinationWebView.NavigateToString("<HTML></HTML>");
        }
    }
}
