﻿using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Data;

namespace Neumann.MVVMHelpers
{
    public class CollectionViewSynchronizer
    {
        public static readonly DependencyProperty SynchronizeWithCurrentItemProperty =
            DependencyProperty.RegisterAttached("SynchronizeWithCurrentItem", typeof(bool), typeof(VisualStateObserver),
            new PropertyMetadata(false, OnSynchronizeWithCurrentItemPropertyChanged));

        public static bool GetSynchronizeWithCurrentItem(UIElement element)
        {
            return (bool)element.GetValue(SynchronizeWithCurrentItemProperty);
        }

        public static void SetSynchronizeWithCurrentItem(UIElement element, bool value)
        {
            element.SetValue(SynchronizeWithCurrentItemProperty, value);
        }

        private static void OnSynchronizeWithCurrentItemPropertyChanged(DependencyObject sender, DependencyPropertyChangedEventArgs e)
        {
            var list = sender as ListViewBase;
            if (list == null) return;
            list.ItemClick += (s, args) =>
            {
                var source = list.ItemsSource as ICollectionView;
                if (source == null) return;
                source.MoveCurrentTo(args.ClickedItem);
            };
        }
    }
}
