﻿using System.Collections;
using System.Windows.Input;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml.Data;

namespace Neumann.MVVMHelpers
{
    public abstract class DetailsViewModelBase : ViewModelBase
    {

        #region Private Variables

        private ICollectionView _itemsView;
        private bool _isInitializing = true;

        #endregion

        #region Constructors

        public DetailsViewModelBase()
        {
            this.VisualStateCommand = new DelegateCommand(this.CanExecuteVisualStateCommand, this.ExecuteVisualStateCommand);
            _isInitializing = true;
        }

        #endregion

        #region Public Properties

        public ICollectionView ItemsView
        {
            get { return _itemsView; }
            set { this.SetProperty<ICollectionView>(ref _itemsView, value); }
        }
        
        #endregion

        #region Protected Members

        #region Command Handling

        /// <summary>
        /// Wird ausgeführt, wenn sich der Visual State ändert, z.B. weil der Benutzer in einen anderen Anzeigemodus gewechselt hat.
        /// </summary>
        /// <remarks>
        /// Über diesen Mechanismus hat das ViewModel die Möglichkeit den Visual State anzupassen, indem sie die Eigenschaft CurrentVisualState verändert.
        /// </remarks>
        /// <param name="parameter">Der aktuelle State.</param>
        protected override void ExecuteVisualStateCommand(object parameter)
        {
            var currentView = parameter as string;
            var logicalPageBack = this.UsingLogicalPageNavigation && (this.ItemsView != null && this.ItemsView.CurrentItem != null);
            if (_isInitializing)
            {
                this.CurrentVisualState = currentView;
                _isInitializing = false;
            }
            else
                this.CurrentVisualState = logicalPageBack ? currentView + "_Detail" : currentView;
        }

        protected override bool CanExecuteVisualStateCommand(object parameter)
        {
            return true;
        }

        #endregion

        #region CollectionView Handling

        protected virtual void ProvideCollectionView(IEnumerable source)
        {
            this.ItemsView = new CollectionViewSource() { Source = source }.View;
            this.ItemsView.CurrentChanged += this.OnCurrentItemChangedCore;
        }

        private void OnCurrentItemChangedCore(object sender, object e)
        {
            if (this.UsingLogicalPageNavigation)
                this.InvalidateVisualState();
            this.OnCurrentItemChanged(sender, e);
        }

        protected virtual void OnCurrentItemChanged(object sender, object e)
        {
        }

        #endregion

        #region Navigation Hanlding

        protected bool UsingLogicalPageNavigation
        {
            get
            {
                return ApplicationView.Value == ApplicationViewState.FullScreenPortrait ||
                       ApplicationView.Value == ApplicationViewState.Snapped;
            }
        }

        protected override void GoBack()
        {
            if (this.UsingLogicalPageNavigation && this.CurrentVisualState.EndsWith("_Detail"))
            {
                this.CurrentVisualState = this.CurrentVisualState.Replace("_Detail", "");
                if (this.ItemsView != null)
                    this.ItemsView.MoveCurrentToPosition(-1);
            }
            else
            {
                base.GoBack();
            }
        }

        #endregion

        #endregion

    }
}
