﻿using System;
using System.Collections.Generic;

namespace Neumann.MVVMHelpers
{
    public class ViewModelMapper
    {
        private static ViewModelMapper _current;
        private static object _lockObject = new object();
        private Dictionary<Type, Type> _mapping;

        private ViewModelMapper()
        {
            _mapping = new Dictionary<Type, Type>();
        }

        public static ViewModelMapper Current
        {
            get
            {
                lock (_lockObject)
                {
                    if (_current == null)
                        _current = new ViewModelMapper();
                    return _current;
                }
            }
        }

        public void Map<TViewModel, TView>()
        {
            if (_mapping.ContainsKey(typeof(TViewModel)))
                throw new ArgumentException("ViewModel type already exists.");
            _mapping.Add(typeof(TViewModel), typeof(TView));
        }

        public Type GetViewType<TViewModel>()
        {
            return this.GetViewType(typeof(TViewModel));
        }

        public Type GetViewType(Type viewModelType)
        {
            if (viewModelType == null) throw new ArgumentNullException("viewModelType");
            if (!_mapping.ContainsKey(viewModelType))
                throw new ArgumentException(string.Format("Can't find mapping for the given view model \"{0}\". Add a mapping!", viewModelType.Name));
            return _mapping[viewModelType];
        }
    }
}
