﻿using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media;

namespace Neumann.MVVMHelpers
{
    public class VisualStateSwitcher : DependencyObject
    {
        public static readonly DependencyProperty StateProperty =
            DependencyProperty.RegisterAttached(
            "State", 
            typeof(string), 
            typeof(VisualStateSwitcher), 
            new PropertyMetadata(null, OnStateChanged));
        
        private static void OnStateChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            if (e.NewValue != null)
            {
                var ctl = FindParent<Control>(d);
                if (ctl != null)
                    VisualStateManager.GoToState(ctl, e.NewValue.ToString(), true);
            }
        }
        
        private static T FindParent<T>(DependencyObject element) where T : DependencyObject
        {
            if (element != null)
            {
                if (element is T)
                    return element as T;
                if (element is FrameworkElement)
                    return FindParent<T>(((FrameworkElement)element).Parent);
            }
            return default(T);
        }

        public static string GetState(UIElement element)
        {
            return element.GetValue(VisualStateSwitcher.StateProperty) as string;
        }

        public static void SetState(UIElement element, string value)
        {
            element.SetValue(VisualStateSwitcher.StateProperty, value);
        }
    }
}
