﻿using System;
using System.Collections.Generic;
using Windows.ApplicationModel.Contacts;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.Storage.Streams;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace PickersDemo
{
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        private async void messageDialog_Click(object sender, RoutedEventArgs e)
        {
            bool? result = null;
            var dialog = new MessageDialog("Wollen Sie das Element wirklich löschen", "Element löschen");
            dialog.Commands.Add(new UICommand("Ja", new UICommandInvokedHandler(cmd => result = true)));
            dialog.Commands.Add(new UICommand("Nein", new UICommandInvokedHandler(cmd => result = false)));
            dialog.DefaultCommandIndex = 0;
            dialog.CancelCommandIndex = 1;
            await dialog.ShowAsync();
            if (result.HasValue && result.Value)
            {
                await new MessageDialog("Element wurde gelöscht!", "Element löschen").ShowAsync();
            }
        }

        private async void fileOpenPicker_Click(object sender, RoutedEventArgs e)
        {
            FileOpenPicker picker = new FileOpenPicker
            {
                ViewMode = PickerViewMode.Thumbnail,
                SuggestedStartLocation = PickerLocationId.PicturesLibrary,
                FileTypeFilter = { ".jpg", ".png", ".bmp", ".gif", ".tif" },
                CommitButtonText = "Öffnen"
            };
            StorageFile file = await picker.PickSingleFileAsync();
            if (file != null)
            {
                await new MessageDialog(file.Name).ShowAsync();
            }
        }

        private async void fileSavePicker_Click(object sender, RoutedEventArgs e)
        {
            FileSavePicker picker = new FileSavePicker();
            picker.SuggestedStartLocation = PickerLocationId.DocumentsLibrary;
            picker.FileTypeChoices.Add("Textdatei", new List<string>() { ".txt" });
            picker.FileTypeChoices.Add("HTML-Datei", new List<string>() { ".html" });
            picker.DefaultFileExtension = ".txt";
            picker.SuggestedFileName = "Notiz";
            StorageFile file = await picker.PickSaveFileAsync();
            if (file != null)
            {
                IRandomAccessStream accessStream = await file.OpenAsync(FileAccessMode.ReadWrite);
                IOutputStream writeStream = accessStream.GetOutputStreamAt(0);
                DataWriter writer = new DataWriter(writeStream);
                writer.WriteString("Test");
                await writer.StoreAsync();
                await writeStream.FlushAsync();
                writer.DetachStream();
            }
        }

        private async void folderPicker_Click(object sender, RoutedEventArgs e)
        {
            FolderPicker picker = new FolderPicker();
            picker.FileTypeFilter.Add(".jpg");
            picker.ViewMode = PickerViewMode.Thumbnail;
            picker.SuggestedStartLocation = PickerLocationId.PicturesLibrary;
            picker.SettingsIdentifier = "FolderPicker";
            picker.CommitButtonText = "Verzeichnis auswählen";
            StorageFolder folder = await picker.PickSingleFolderAsync();
            if (folder != null)
            {
                await new MessageDialog(folder.Name).ShowAsync();
            }
        }

        private async void contactPicker_Click(object sender, RoutedEventArgs e)
        {
            ContactPicker picker = new ContactPicker();
            picker.DesiredFields.Add(Windows.ApplicationModel.Contacts.KnownContactField.Email);
            picker.SelectionMode = ContactSelectionMode.Contacts;
            IReadOnlyList<ContactInformation> contactList = await picker.PickMultipleContactsAsync();
            if (contactList != null)
            {
                foreach (var contact in contactList)
                {
                    await new MessageDialog(contact.Emails[0].Value).ShowAsync();
                }
            }
        }
    }
}
