﻿using System;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace UserControlDemo
{
    public sealed partial class FileBox : UserControl
    {
        public FileBox()
        {
            this.InitializeComponent();
            this.fileNameTextBox.DataContext = this;
        }

        public string FileName
        {
            get { return (string)GetValue(FileNameProperty); }
            set { SetValue(FileNameProperty, value); }
        }

        public static readonly DependencyProperty FileNameProperty =
            DependencyProperty.Register("FileName", typeof(string), typeof(FileBox),
            new PropertyMetadata(string.Empty, OnFileNamePropertyChanged));

        private static void OnFileNamePropertyChanged(DependencyObject sender, DependencyPropertyChangedEventArgs e)
        {
            ((FileBox)sender).OnFileNameChanged();
        }

        public event EventHandler FileNameChanged;
        private void OnFileNameChanged()
        {
            if (FileNameChanged != null)
                FileNameChanged(this, EventArgs.Empty);
        }

        public string FileTypeFilter
        {
            get { return (string)GetValue(FileTypeFilterProperty); }
            set { SetValue(FileTypeFilterProperty, value); }
        }

        public static readonly DependencyProperty FileTypeFilterProperty =
            DependencyProperty.Register("FileTypeFilter", typeof(string), typeof(FileBox), new PropertyMetadata("*.*"));


        public string FilePickerCommitButtonText
        {
            get { return (string)GetValue(FilePickerCommitButtonTextProperty); }
            set { SetValue(FilePickerCommitButtonTextProperty, value); }
        }

        public static readonly DependencyProperty FilePickerCommitButtonTextProperty =
            DependencyProperty.Register("FilePickerTitle", typeof(string), typeof(FileBox), new PropertyMetadata("Open"));

        private async void OnSearchButtonClick(object sender, RoutedEventArgs e)
        {
            var picker = new FileOpenPicker
            {
                ViewMode = PickerViewMode.Thumbnail,
                SuggestedStartLocation = PickerLocationId.PicturesLibrary,
                FileTypeFilter = { this.FileTypeFilter },
                CommitButtonText = this.FilePickerCommitButtonText
            };
            StorageFile file = await picker.PickSingleFileAsync();
            if (file != null)
            {
                this.FileName = file.Path;
            }
        }
    }
}
