﻿using VisualStatesDemo.Common;
using VisualStatesDemo.Model;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Navigation;

namespace VisualStatesDemo
{
    public sealed partial class MainPage : Page
    {
        public ICollectionView ItemsView { get; set; }
        private Fruit _currentEditItem;

        public MainPage()
        {
            this.InitializeComponent();
            this.SizeChanged += MainPage_SizeChanged;
        }

        private void MainPage_SizeChanged(object sender, SizeChangedEventArgs e)
        {
            this.HandleStates(false);
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            this.ItemsView = new CollectionViewSource() { Source = new FruitsRepository().Fruits }.View;
            this.ItemsView.MoveCurrentToFirst();
            this.DataContext = this.ItemsView;
        }

        private void editButton_Click_1(object sender, RoutedEventArgs e)
        {
            this.HandleStates(true);
            if (ApplicationView.Value != ApplicationViewState.Snapped)
            {
                this.topAppBar.IsOpen = false;
                var fruid = this.ItemsView.CurrentItem as Fruit;
                _currentEditItem = new Fruit { Name = fruid.Name, ImageUri = fruid.ImageUri };
            }
        }

        private void cancelButton_Click_1(object sender, RoutedEventArgs e)
        {
            this.HandleStates(false);
            this.topAppBar.IsOpen = false;
            var fruid = this.ItemsView.CurrentItem as Fruit;
            fruid.Name = _currentEditItem.Name;
            fruid.ImageUri = _currentEditItem.ImageUri;
        }

        private void okButton_Click_1(object sender, RoutedEventArgs e)
        {
            this.HandleStates(false);
            this.topAppBar.IsOpen = false;
        }

        private void HandleStates(bool editMode)
        {
            if (ApplicationView.Value == ApplicationViewState.Snapped)
            {
                VisualStateManager.GoToState(this, "Snapped", false);
            }
            else if (editMode)
            {
                VisualStateManager.GoToState(this, "Edit", false);
            }
            else
            {
                VisualStateManager.GoToState(this, "Normal", false);
            }
        }
    }
}
