﻿using PushNotificationService.Models;
using System.IO;
using System.Net;
using System.Runtime.Serialization.Json;
using System.Text;
using System.Web;

namespace PushNotificationService.Services
{
    public class PushNotificationManager
    {
        // Hier die Paket-Sicherheits-ID (SID) und der geheime Clientschlüssel (Client Secret) hinterlegen!
        private const string CLIENT_ID = "ms-app://***";
        private const string CLIENT_SECRET = "***";

        private static string AccessToken { get; set; }

        private static string GetAccessToken()
        {
            var body = string.Format(
                "grant_type=client_credentials&client_id={0}&client_secret={1}&scope=notify.windows.com",
                HttpUtility.UrlEncode(CLIENT_ID),
                HttpUtility.UrlEncode(CLIENT_SECRET));

            using (var client = new WebClient())
            {
                client.Headers.Add("Content-Type", "application/x-www-form-urlencoded");
                string response = client.UploadString("https://login.live.com/accesstoken.srf", body);
                var oAuthToken = GetOAuthTokenFromJson(response);
                return oAuthToken.AccessToken;
            }
        }

        private static OAuthToken GetOAuthTokenFromJson(string jsonString)
        {
            using (var stream = new MemoryStream(Encoding.Unicode.GetBytes(jsonString)))
            {
                var serializer = new DataContractJsonSerializer(typeof(OAuthToken));
                var oAuthToken = (OAuthToken)serializer.ReadObject(stream);
                return oAuthToken;
            }
        }

        public static void PushNotification(string channelUri, string notificationXml, string tag = null)
        {
            if (AccessToken == null)
                AccessToken = GetAccessToken();
            try
            {
                using (var client = new WebClient())
                {
                    // Authentifizierungs-Header füllen
                    client.Headers.Add("Authorization", string.Format("Bearer {0}", HttpUtility.UrlEncode(AccessToken)));

                    // Content Types festlegen
                    client.Headers.Add("Content-Type", "text/xml");
                    client.Headers.Add("X-WNS-Type", "wns/tile");
                    
                    // ggf. Tile-Tag hinzufügen
                    if (tag != null)
                        client.Headers.Add("X-WNS-Tag", tag);

                    // Tile als Binärdaten hochladen
                    byte[] content = Encoding.UTF8.GetBytes(notificationXml);
                    client.UploadData(channelUri, content);
                }
            }
            catch (WebException webException)
            {
                //// Falls der Zugriffs-Token abgelaufen ist, automatisch einen neuen anfordern
                string exceptionDetails = webException.Response.Headers["WWW-Authenticate"];
                if ((exceptionDetails != null) && exceptionDetails.Contains("Token expired"))
                {
                    AccessToken = GetAccessToken();
                    PushNotification(channelUri, notificationXml, tag);
                }
                else
                {
                    throw;
                }
            }
        }
    }
}