﻿using System;
using System.Collections.Generic;
using Windows.Data.Xml.Dom;
using Windows.UI.Notifications;
using Windows.UI.Popups;
using Windows.UI.StartScreen;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TilesDemo
{
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        private void writeTextButton_Click(object sender, RoutedEventArgs e)
        {
            string tileMessage = string.Format(
                "<tile>" +
                    "<visual>" +
                        "<binding template='TileWideImageAndText01'>" +
                            "<image id='1' src='ms-appx:///Assets/Wide.png'/>" +
                            "<text id='1'>{0}</text>" +
                        "</binding>" +
                        "<binding template='TileSquareText01'>" +
                              "<text id='1'>{0}</text>" +
                        "</binding>" +
                    "</visual>" +
                "</tile>", this.messageTextBox.Text);
            
            XmlDocument document = new XmlDocument();
            document.LoadXml(tileMessage);

            #region Ad-Hoc-Benachrichtigungen

            TileNotification tile = new TileNotification(document);
            tile.ExpirationTime = new DateTimeOffset(DateTime.Now.AddSeconds(60));
            TileUpdater updater = TileUpdateManager.CreateTileUpdaterForApplication();
            updater.EnableNotificationQueue(true);
            if (updater.Setting == NotificationSetting.Enabled)
                updater.Update(tile);

            #endregion

            #region Nachricht über einen Zeitplan verteilen:
            
            //ScheduledTileNotification scheduledNotification = new ScheduledTileNotification(
            //    document, new DateTimeOffset(DateTime.Now.AddSeconds(60)));
            //scheduledNotification.Id = "1";
            //TileUpdater updater = TileUpdateManager.CreateTileUpdaterForApplication();
            //updater.AddToSchedule(scheduledNotification);

            #endregion

            #region Geplante Nachricht entfernen

            //IReadOnlyList<ScheduledTileNotification> list = updater.GetScheduledTileNotifications();
            //for (int i = 0; i < list.Count; i++)
            //{
            //    if (list[i].Id == "1")
            //        updater.RemoveFromSchedule(list[i]);
            //}

            #endregion

            #region Periodisches Update per WebService

            //Uri uri = new Uri("http://localhost:9777/Tiles/GetTile");
            //TileUpdater updater = TileUpdateManager.CreateTileUpdaterForApplication();
            //updater.StartPeriodicUpdate(uri, PeriodicUpdateRecurrence.HalfHour);

            #endregion

            #region Periodisches Batch-Update per WebService

            //List<Uri> list = new List<Uri>()
            //{
            //    new Uri("http://localhost:9777/Tiles/GetTile/1"),
            //    new Uri("http://localhost:9777/Tiles/GetTile/2")
            //};
            //TileUpdater updater = TileUpdateManager.CreateTileUpdaterForApplication();
            //updater.EnableNotificationQueue(true);
            //updater.StartPeriodicUpdateBatch(list, PeriodicUpdateRecurrence.HalfHour);

            #endregion

        }

        private void textAndImageButton_Click(object sender, RoutedEventArgs e)
        {
            string tileMessage =
                "<tile>" +
                    "<visual>" +
                        "<binding template='TileWidePeekImage02'>" +
                            "<image id='1' src='ms-appx:///Assets/Wide.png' alt='image'/>" +
                            "<text id='1'>Windows Store Apps</text>" +
                            "<text id='2'>entwickeln</text>" +
                            "<text id='3'>mit C# und XAML</text>" +
                        "</binding>" +
                        "<binding template='TileSquarePeekImageAndText01'>" +
                            "<image id='1' src='ms-appx:///Assets/Square.png' alt='image'/>" +
                            "<text id='1'>Windows Store Apps</text>" +
                            "<text id='2'>entwickeln</text>" +
                            "<text id='3'>mit C# und XAML</text>" +
                        "</binding>" +
                    "</visual>" +
                "</tile>";

            XmlDocument document = new XmlDocument();
            document.LoadXml(tileMessage);

            TileNotification tile = new TileNotification(document);
            TileUpdater updater = TileUpdateManager.CreateTileUpdaterForApplication();
            updater.EnableNotificationQueue(true);
            if (updater.Setting == NotificationSetting.Enabled)
            {
                updater.Update(tile);
            }
        }

        private void sendBadgeButton_Click(object sender, RoutedEventArgs e)
        {
            string badgeMessage = string.Format(
                "<badge key='1' value='{0}' version='1'/>", this.badgeTextBox.Text);

            XmlDocument document = new XmlDocument();
            document.LoadXml(badgeMessage);

            BadgeNotification badge = new BadgeNotification(document);
            BadgeUpdateManager.CreateBadgeUpdaterForApplication().Update(badge);
        }

        private void sendSymbolBadgeButton_Click(object sender, RoutedEventArgs e)
        {
            string badgeMessage = "<badge key='1' value='activity'/>";

            XmlDocument document = new XmlDocument();
            document.LoadXml(badgeMessage);

            BadgeNotification badge = new BadgeNotification(document);
            BadgeUpdater updater = BadgeUpdateManager.CreateBadgeUpdaterForApplication();
            updater.Update(badge);
        }

        private async void createSecondaryTileButton_Click(object sender, RoutedEventArgs e)
        {
            // Vorhandene Secondary Tiles löschen
            IReadOnlyList<SecondaryTile> list = await SecondaryTile.FindAllForPackageAsync();
            foreach (SecondaryTile item in list)
            {
                await item.RequestDeleteAsync();
            }

            // Secondary Tile erstellen
            string shortName = "Test";
            string displayName = "TilesDemo: Test" + this.secondaryTextBox.Text;
            string id = "1";
            string args = id;

            if (!SecondaryTile.Exists(id))
            {
                SecondaryTile tile = new SecondaryTile(
                    id, 
                    shortName, 
                    displayName, 
                    args,
                    TileOptions.ShowNameOnLogo | TileOptions.ShowNameOnWideLogo,
                    new Uri("ms-appx:///Assets/Square.png"),
                    new Uri("ms-appx:///Assets/Wide.png"));

                #region Optional: Symbol auf dem Lock Screen anzeigen

                //await BackgroundExecutionManager.RequestAccessAsync();

                #endregion

                tile.LockScreenDisplayBadgeAndTileText = true;
                tile.LockScreenBadgeLogo = new Uri("ms-appx:///Assets/Caret.png");
                
                bool created = await tile.RequestCreateAsync();
                if (!created)
                {
                    await new MessageDialog("Erstellung fehlgeschlagen!").ShowAsync();
                    return;
                }

                #region Alternativ: Sicherheitsabfrage an einer bestimmten Stelle positionieren

                //bool created = await tile.RequestCreateForSelectionAsync(
                //    new Rect(0, 0, Window.Current.Bounds.Width, Window.Current.Bounds.Height), Placement.Below);

                #endregion

            }

             //Tile-Nachricht anzeigen
            string tileMessage = string.Format(
                "<tile>" +
                    "<visual>" +
                        "<binding template='TileWideText01'>" +
                            "<text id='1'>{0}</text>" +
                        "</binding>" +
                        "<binding template='TileSquareText01'>" +
                                "<text id='1'>{0}</text>" +
                        "</binding>" +
                    "</visual>" +
                "</tile>", this.badgeTextBox.Text);
            XmlDocument document = new XmlDocument();
            document.LoadXml(tileMessage);
            TileNotification notification = new TileNotification(document);
            TileUpdater updater = TileUpdateManager.CreateTileUpdaterForSecondaryTile(id);
            updater.Update(notification);

            // Badge-Nachricht anzeigen
            XmlDocument badgeDocument = new XmlDocument();
            badgeDocument.LoadXml("<badge value='1'/>");
            BadgeNotification badge = new BadgeNotification(badgeDocument);
            BadgeUpdater badgeUpdater = BadgeUpdateManager.CreateBadgeUpdaterForSecondaryTile(id);
            badgeUpdater.Update(badge);
        }

        private void sendToastButton_Click(object sender, RoutedEventArgs e)
        {
            string message = string.Format(
                "<toast duration='short' launch='id=1'>" +
                    "<visual>" +
                        "<binding template='ToastImageAndText01'>" +
                            "<image id='1' src='ms-appx:///Assets/Toast.png' alt='image'/>" +
                            "<text id='1'>{0}</text>" +
                        "</binding>" +
                    "</visual>" +
                    "<audio src='ms-winsoundevent:Notification.Default'/>" +
                "</toast>", this.toastTextBox.Text);

            #region Toast mit langer Anzeigedauer und looped Audio

            //string message = string.Format(
            //    "<toast duration='long'>" +
            //        "<visual>" +
            //            "<binding template='ToastImageAndText01'>" +
            //                "<image id='1' src='ms-appx:///Assets/Square.png' alt='image'/>" +
            //                "<text id='1'>{0}</text>" +
            //            "</binding>" +
            //        "</visual>" +
            //        "<audio src='ms-winsoundevent:Looping.Alarm' loop='true'/>" +
            //    "</toast>", this.toastTextBox.Text); 

            #endregion

            XmlDocument document = new XmlDocument();
            document.LoadXml(message);

            ToastNotification notification = new ToastNotification(document);
            notification.ExpirationTime = new DateTimeOffset(DateTime.Now.AddSeconds(3));
            notification.Failed += this.OnNotificationFailed;
            ToastNotifier notifier = ToastNotificationManager.CreateToastNotifier();
            notifier.Show(notification);

            #region Zeitgesteuerte Toasts

            //ScheduledToastNotification scheduledNotification = new ScheduledToastNotification(
            //    document, DateTime.Now.AddSeconds(3));
            //ToastNotifier notifier2 = ToastNotificationManager.CreateToastNotifier();
            //notifier2.AddToSchedule(scheduledNotification);
            //IReadOnlyList<ScheduledToastNotification> list = notifier2.GetScheduledToastNotifications();
            //for (int i = 0; i < list.Count; i++)
            //{
            //    notifier2.RemoveFromSchedule(list[i]);
            //}

            #endregion

        }

        private async void OnNotificationFailed(ToastNotification sender, ToastFailedEventArgs args)
        {
            await new MessageDialog("Fehler beim Auslösen des Toast: " + args.ErrorCode.Message).ShowAsync();
        }
    }
}
