﻿using System;
using System.Linq;
using System.Collections.Generic;
using Windows.Storage;
using Windows.Storage.AccessCache;
using Windows.Storage.Pickers;
using Windows.Storage.Streams;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media.Imaging;
using Windows.UI.Xaml.Navigation;

namespace StorageDemo
{
    public sealed partial class MainPage : Page
    {
        private StorageFile _currentFile;
        public string DirectoryName { get; set; }

        public MainPage()
        {
            this.InitializeComponent();

            // Aktuellen Speicherort ausgeben
            this.DirectoryName = "Speicherort: " + KnownFolders.DocumentsLibrary.DisplayName;
            this.DataContext = this;

            // Zuletzt verwendete Dateien ermitteln
            var recentFileList = new List<RecentFileItem>();
            foreach (var item in StorageApplicationPermissions.FutureAccessList.Entries)
            {
                var recentFile = new RecentFileItem()
                {
                    DisplayName = item.Metadata,
                    Token = item.Token
                };
                recentFileList.Add(recentFile);
            }
            this.lastFilesListBox.ItemsSource = recentFileList;
            this.lastFilesListBox.DisplayMemberPath = "DisplayName";
        }

        private async void openButton_Click_1(object sender, RoutedEventArgs e)
        {
            // Datei öffnen
            StorageFolder folder = KnownFolders.DocumentsLibrary;
            StorageFile file = await folder.GetFileAsync("sample.txt");
            
            // Textdatei einlesen
            string content = null;
            content = await FileIO.ReadTextAsync(file);
            
            // Alternativ: Textdatei zeilenweise einlesen:
            //IList<string> list = await FileIO.ReadLinesAsync(file);
            //content = string.Concat<string>(list);
            
            // Alternativ: Datei gepuffert einlesen:
            //var buffer = await FileIO.ReadBufferAsync(file);
            //var reader = DataReader.FromBuffer(buffer);
            //content = reader.ReadString(buffer.Length);
            
            this.contentTextBox.Text = content;
            _currentFile = file;
        }

        private async void selectButton_Click_1(object sender, RoutedEventArgs e)
        {
            // Datei mit FileOpenPicker auswählen
            var picker = new FileOpenPicker();
            picker.SuggestedStartLocation = PickerLocationId.DocumentsLibrary;
            picker.FileTypeFilter.Add(".txt");
            var file = await picker.PickSingleFileAsync();
            if (file != null)
            {
                var content = await FileIO.ReadTextAsync(file);
                this.contentTextBox.Text = content;
                StorageApplicationPermissions.FutureAccessList.Add(file, file.DisplayName);
                _currentFile = file;
            }
        }

        private async void saveButton_Click_1(object sender, RoutedEventArgs e)
        {
            // Datei speichern
            var content = this.contentTextBox.Text;
            if (_currentFile == null)
            {
                StorageFolder folder = KnownFolders.DocumentsLibrary;
                _currentFile = await folder.CreateFileAsync("Sample.txt", CreationCollisionOption.ReplaceExisting);
            }
            await FileIO.WriteTextAsync(_currentFile, content);

            // Alternativ: Datei per Stream ermitteln
            //var stream = await _currentFile.OpenAsync(FileAccessMode.ReadWrite);
            //using (IOutputStream outputStream = stream.GetOutputStreamAt(0))
            //{
            //    DataWriter writer = new DataWriter(outputStream);
            //    writer.WriteString(content);
            //    await writer.StoreAsync();
            //}
        }

        private async void saveAsButton_Click_1(object sender, RoutedEventArgs e)
        {
            // Datei mit FileSavePicker speichern
            var picker = new FileSavePicker();
            picker.SuggestedStartLocation = PickerLocationId.DocumentsLibrary;
            picker.FileTypeChoices.Add("Textdatei", new List<string>() { ".txt" });
            picker.SuggestedSaveFile = _currentFile;
            var file = await picker.PickSaveFileAsync();
            if (file != null)
            {
                var content = this.contentTextBox.Text;
                await FileIO.WriteTextAsync(file, content);
                StorageApplicationPermissions.FutureAccessList.Add(file, file.DisplayName);
                _currentFile = file;
            }
        }

        private async void lastFilesListBox_SelectionChanged_1(object sender, SelectionChangedEventArgs e)
        {
            // Eine zuletzt verwendete Datei öffnen
            var listBox = sender as ListBox;
            var recentFile = listBox.SelectedItem as RecentFileItem;
            StorageFolder folder = KnownFolders.DocumentsLibrary;
            StorageFile file = await StorageApplicationPermissions.FutureAccessList.GetFileAsync(recentFile.Token);
            var content = await FileIO.ReadTextAsync(file);
            this.contentTextBox.Text = content;
            _currentFile = file;
        }

        private async void openImageButton_Click_1(object sender, RoutedEventArgs e)
        {
            // Ein Bild öffnen und zweisen
            var picker = new FileOpenPicker();
            picker.SuggestedStartLocation = PickerLocationId.PicturesLibrary;
            picker.FileTypeFilter.Add(".png");
            var file = await picker.PickSingleFileAsync();
            if (file != null)
            {
                IRandomAccessStream stream = await file.OpenAsync(FileAccessMode.Read);

                // Bitmap anzeigen
                BitmapImage bitmap = new BitmapImage();
                bitmap.SetSource(stream);
                this.image1.Source = bitmap;
            }
        }
    }
}
