﻿using System;
using System.IO;
using System.Net;
using System.Net.Http;
using System.Net.NetworkInformation;
using Windows.Storage.Streams;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Media.Imaging;
using System.Linq;
using Windows.Security.Credentials.UI;
using Windows.Networking.Connectivity;
using Windows.UI.Core;
using Windows.UI.Popups;
using System.Collections.Generic;

namespace HttpClientDemo
{
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        protected async override void OnNavigatedTo(Windows.UI.Xaml.Navigation.NavigationEventArgs e)
        {
            var defaultCredentials = CredentialCache.DefaultCredentials;
            var networkCredentials = CredentialCache.DefaultNetworkCredentials;
            
            // Benutzerdaten ermitteln
            this.userTextBlock.Text = await Windows.System.UserProfile.UserInformation.GetDisplayNameAsync();
            var file = Windows.System.UserProfile.UserInformation.GetAccountPicture(Windows.System.UserProfile.AccountPictureKind.SmallImage);
            BitmapImage bitmapImage = new BitmapImage();
            IRandomAccessStream stream = await file.OpenAsync(Windows.Storage.FileAccessMode.Read);
            bitmapImage.SetSource(stream);
            this.userImage.Source = bitmapImage;
            
            NetworkInformation.NetworkStatusChanged += NetworkInformation_NetworkStatusChanged;
            
            // Aktuelle Internetverbindung ermitteln
            IReadOnlyList<ConnectionProfile> profileList = Windows.Networking.Connectivity.NetworkInformation.GetConnectionProfiles();
            foreach (var profile in profileList)
            {
                if (profile.GetNetworkConnectivityLevel() == NetworkConnectivityLevel.InternetAccess)
                {
                    var name = profile.GetNetworkNames()[0];
                }
            }

            // Netzwerkstatus ermitteln
            this.OnNetworkAddressChanged(null, EventArgs.Empty);
            NetworkChange.NetworkAddressChanged += this.OnNetworkAddressChanged;
        }

        void NetworkInformation_NetworkStatusChanged(object sender)
        {
        }

        private async void OnNetworkAddressChanged(object sender, EventArgs e)
        {
            bool isOnline = NetworkInterface.GetIsNetworkAvailable();
            await this.statusTextBlock.Dispatcher.RunAsync(CoreDispatcherPriority.Normal,
                () => this.statusTextBlock.Text = isOnline ? "(Online)" : "(Offline)");
        }

        private async void downloadImage_Click(object sender, Windows.UI.Xaml.RoutedEventArgs e)
        {
            this.progressBar.Visibility = Visibility.Visible;
            string uri = "http://i.s-microsoft.com/global/ImageStore/PublishingImages/logos/hp/logo-lg-1x.png";
            using (HttpClient client = new HttpClient())
            {
                HttpResponseMessage response = await client.GetAsync(uri);
                if (response.StatusCode == HttpStatusCode.OK)
                {
                    MemoryStream stream = await response.Content.ReadAsStreamAsync() as MemoryStream;
                    IRandomAccessStream accessStream = await stream.ToRandomAccessStreamAsync();
                    var bitmap = new BitmapImage();
                    await bitmap.SetSourceAsync(accessStream);
                    this.contentImage.Source = bitmap;
                }
            }
            this.progressBar.Visibility = Visibility.Collapsed;
        }

        private async void downloadText_Click(object sender, Windows.UI.Xaml.RoutedEventArgs e)
        {
            this.progressBar.Visibility = Visibility.Visible;
            string uri = "http://windows.microsoft.com/en-US/windows-8/meet";
            using (HttpClient client = new HttpClient())
            {
                HttpResponseMessage response = await client.GetAsync(uri);
                if (response.StatusCode == HttpStatusCode.OK)
                {
                    string content = await response.Content.ReadAsStringAsync();
                    this.contentTextBox.Text = content;
                }
            }
            this.progressBar.Visibility = Visibility.Collapsed;
        }
        
    }


}
