﻿using System;
using System.IO;
using Windows.Foundation;
using Windows.Storage.Streams;

namespace HttpClientDemo
{
    public class RandomAccessStream : IRandomAccessStream
    {
        private Stream _innerStream;

        public RandomAccessStream(Stream stream)
        {
            _innerStream = stream;
        }

        public RandomAccessStream(byte[] bytes)
        {
            _innerStream = new MemoryStream(bytes);
        }

        public IInputStream GetInputStreamAt(ulong position)
        {
            _innerStream.Seek((long)position, SeekOrigin.Begin);
            return _innerStream.AsInputStream();
        }

        public IOutputStream GetOutputStreamAt(ulong position)
        {
            _innerStream.Seek((long)position, SeekOrigin.Begin);
            return _innerStream.AsOutputStream();
        }

        public ulong Size
        {
            get { return (ulong)_innerStream.Length; }
            set { _innerStream.SetLength((long)value); }
        }

        public bool CanRead
        {
            get { return true; }
        }

        public bool CanWrite
        {
            get { return true; }
        }

        public IRandomAccessStream CloneStream()
        {
            throw new NotSupportedException();
        }

        public ulong Position
        {
            get { return (ulong)_innerStream.Position; }
        }

        public void Seek(ulong position)
        {
            _innerStream.Seek((long)position, 0);
        }

        public void Dispose()
        {
            _innerStream.Dispose();
        }

        public IAsyncOperationWithProgress<IBuffer, uint> ReadAsync(IBuffer buffer, uint count, InputStreamOptions options)
        {
            return this.GetInputStreamAt(0).ReadAsync(buffer, count, options);
        }

        public IAsyncOperation<bool> FlushAsync()
        {
            return this.GetOutputStreamAt(0).FlushAsync();
        }

        public IAsyncOperationWithProgress<uint, uint> WriteAsync(IBuffer buffer)
        {
            return this.GetOutputStreamAt(0).WriteAsync(buffer);
        }
    }
}
