﻿using System;
using System.IO;
using System.Threading.Tasks;
using Windows.Storage.Streams;

namespace HttpClientDemo
{
    public static class RandomAccessStreamExtensions
    {
        public static async Task<IRandomAccessStream> ToRandomAccessStreamAsync(this Stream stream)
        {
            if (!stream.CanRead)
                throw new InvalidOperationException("Can't read from source stream!");
            
            Stream sourceStream = null;
            if (stream.CanSeek)
            {
                sourceStream = stream;
            }
            else
            {
                MemoryStream memStream = new MemoryStream();
                await stream.CopyToAsync(memStream);
                sourceStream = memStream;
            }

            DataReader reader = new DataReader(sourceStream.AsInputStream());
            sourceStream.Position = 0;
            await reader.LoadAsync((uint)sourceStream.Length);
            IBuffer buffer = reader.ReadBuffer((uint)sourceStream.Length);
            InMemoryRandomAccessStream randomAccessStream = new InMemoryRandomAccessStream();
            IOutputStream outputStream = randomAccessStream.GetOutputStreamAt(0);
            await outputStream.WriteAsync(buffer);
            await outputStream.FlushAsync();
            return randomAccessStream;
        }
    }
}
