﻿using System.Collections.Generic;
using System.IO;
using System.Net.Http;
using System.Runtime.Serialization.Json;
using System.Text;
using System.Threading.Tasks;

namespace RestDemo
{
    public class PersonServiceClient
    {
        private readonly string _baseUri;

        public PersonServiceClient(string baseUri)
	    {
            _baseUri = baseUri;
            if (!_baseUri.EndsWith("/"))
                _baseUri += "/";
	    }
        
        public async Task<IEnumerable<Person>> GetPersonsAsync()
        {
            using (HttpClient client = new HttpClient())
            {
                // Daten ermitteln
                HttpResponseMessage response = await client.GetAsync(_baseUri);
                Stream stream = await response.Content.ReadAsStreamAsync();

                // Daten deserialisieren
                DataContractJsonSerializer serializer = new DataContractJsonSerializer(typeof(Person[]));
                Person[] personList = serializer.ReadObject(stream) as Person[];
                return personList;
            }
        }

        public async Task<Person> GetPersonAsync(int id)
        {
            string uri = _baseUri + id;
            using (HttpClient client = new HttpClient())
            {
                // Daten ermitteln
                HttpResponseMessage response = await client.GetAsync(uri);
                string jsonResponse = await response.Content.ReadAsStringAsync();

                // Daten deserialisieren
                DataContractJsonSerializer serializer = new DataContractJsonSerializer(typeof(Person));
                using (MemoryStream stream = new MemoryStream(Encoding.Unicode.GetBytes(jsonResponse)))
                {
                    return serializer.ReadObject(stream) as Person;
                }
            }
        }

        public async Task<Person> InsertPersonAsync(Person person)
        {
            // JSON aus Objekt erzeugen
            DataContractJsonSerializer serializer = new DataContractJsonSerializer(typeof(Person));
            using (MemoryStream stream = new MemoryStream())
            {
                serializer.WriteObject(stream, person);
                var bytes = stream.ToArray();
                string jsonString = UTF8Encoding.UTF8.GetString(bytes, 0, bytes.Length);

                // HTTP PUT-Operation ausführen
                using (HttpClient client = new HttpClient())
                {
                    using (HttpContent httpContent = new StringContent(jsonString, Encoding.UTF8, "application/json"))
                    {
                        HttpResponseMessage response = await client.PutAsync(_baseUri, httpContent);

                        // Rückgabe verarbeiten
                        Stream readStream = await response.Content.ReadAsStreamAsync();
                        return serializer.ReadObject(readStream) as Person;
                    }
                }
            }
        }

        public async Task<Person> UpdatePersonAsync(Person person)
        {
            // JSON aus Objekt erzeugen
            DataContractJsonSerializer serializer = new DataContractJsonSerializer(typeof(Person));
            using (MemoryStream stream = new MemoryStream())
            {
                serializer.WriteObject(stream, person);
                var bytes = stream.ToArray();
                string jsonString = UTF8Encoding.UTF8.GetString(bytes, 0, bytes.Length);

                // HTTP POST-Operation ausführen
                using (HttpClient client = new HttpClient())
                {
                    using (HttpContent httpContent = new StringContent(jsonString, Encoding.UTF8, "application/json"))
                    {
                        HttpResponseMessage response = await client.PostAsync(_baseUri, httpContent);

                        // Rückgabe verarbeiten
                        Stream readStream = await response.Content.ReadAsStreamAsync();
                        return serializer.ReadObject(readStream) as Person;
                    }
                }
            }
        }

        public async Task DeletePersonAsync(int id)
        {
            // HTTP DELETE-Operation ausführen
            string uri = _baseUri + id;
            using (HttpClient client = new HttpClient())
            {
                HttpResponseMessage response = await client.DeleteAsync(uri);
            }
        }
    }
}
