﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ServiceModel;

namespace PersonService
{
    [ServiceBehavior(InstanceContextMode=InstanceContextMode.Single)]
    public class PersonService : IPersonService
    {
        private List<Person> _persons;
        
        public PersonService()
        {
            _persons = new List<Person>()
            {
                new Person { Id = 1, FirstName = "Bob", LastName = "Miller" },
                new Person { Id = 2, FirstName = "Bill", LastName = "Grossmann" },
                new Person { Id = 3, FirstName = "Gil", LastName = "Meiers" },
                new Person { Id = 4, FirstName = "Tim", LastName = "Harrison" },
                new Person { Id = 5, FirstName = "Mary", LastName = "Stevens" }
            };
        }

        public IEnumerable<Person> GetPersons()
        {
            return _persons;
        }

        public Person GetPerson(int id)
        {
            return (from p in _persons where p.Id == id select p).FirstOrDefault();
        }

        public Person InsertPerson(Person person)
        {
            var id = _persons.Max(p => { return p.Id; }) + 1;
            person.Id = id;
            _persons.Add(person);
            return person;
        }

        public Person UpdatePerson(Person person)
        {
            var item = (from p in _persons where p.Id == person.Id select p).FirstOrDefault();
            if (item != null)
            {
                item.FirstName = person.FirstName;
                item.LastName = person.LastName;
            }
            return person;
        }

        public void DeletePerson(int id)
        {
            var item = (from p in _persons where p.Id.Equals(id) select p).FirstOrDefault();
            if (item != null)
            {
                _persons.Remove(item);
            }
            else
                throw new ArgumentException();
        }
    }
}
