﻿using SoapDemo.PersonServiceReference;
using System.Collections.ObjectModel;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

namespace SoapDemo
{
    public sealed partial class MainPage : Page
    {
        private PersonServiceClient _personService;
        private ObservableCollection<Person> _personList;
        private Person _selectedPerson;
        private bool _isInserting;

        public MainPage()
        {
            this.InitializeComponent();
        }

        protected override async void OnNavigatedTo(NavigationEventArgs e)
        {
            // Personenliste ermitteln
            this.progressBar.Visibility = Visibility.Visible;
            _personService = new PersonServiceClient();
            _personList = await _personService.GetPersonsAsync();
            this.dataListBox.ItemsSource = _personList;
            if (_personList.Count > 0)
                this.dataListBox.SelectedItem = _personList[0];
            this.progressBar.Visibility = Visibility.Collapsed;
        }

        private void dataListBox_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            // Selektierte Person im Detailbereich anzeigen
            if (e.AddedItems.Count == 0) return;
            _selectedPerson = e.AddedItems[0] as Person;
            this.DataContext = _selectedPerson;
        }

        private void addButton_Click(object sender, RoutedEventArgs e)
        {
            _isInserting = true;
            _selectedPerson = new Person();
            this.DataContext = _selectedPerson;
        }

        private async void deleteButton_Click(object sender, RoutedEventArgs e)
        {
            if (_isInserting)
            {
                _isInserting = false;
            }
            else
            {
                if (_selectedPerson != null)
                {
                    // Person löschen
                    this.progressBar.Visibility = Visibility.Visible;
                    await _personService.DeletePersonAsync(_selectedPerson.Id);
                    _personList.Remove(_selectedPerson);
                    this.progressBar.Visibility = Visibility.Collapsed;
                }
            }
            _selectedPerson = null;
            this.DataContext = null;
            this.dataListBox.SelectedItem = null;
            if (_personList.Count > 0)
            {
                _selectedPerson = _personList[0];
                this.DataContext = _selectedPerson;
                this.dataListBox.SelectedItem = _selectedPerson;
            }
        }

        private async void saveButton_Click(object sender, RoutedEventArgs e)
        {
            if (_selectedPerson != null)
            {
                this.progressBar.Visibility = Visibility.Visible;
                if (_isInserting)
                {
                    // Neue Person einfügen
                    Person person = await _personService.InsertPersonAsync(_selectedPerson);
                    _personList.Add(person);
                    this.dataListBox.SelectedItem = person;
                    _isInserting = false;
                }
                else
                {
                    // Vorhandene Person aktualisieren
                    await _personService.UpdatePersonAsync(_selectedPerson);
                }
                this.progressBar.Visibility = Visibility.Collapsed;
            }
        }

        private async void refreshButton_Click(object sender, RoutedEventArgs e)
        {
            // Personenliste ermitteln
            this.progressBar.Visibility = Visibility.Visible;
            _personList = new ObservableCollection<Person>(await _personService.GetPersonsAsync());
            this.dataListBox.ItemsSource = _personList;
            this.progressBar.Visibility = Visibility.Collapsed;
        }
    }
}
