﻿using System;
using Windows.ApplicationModel;
using Windows.ApplicationModel.Store;
using Windows.Globalization.DateTimeFormatting;
using Windows.Storage;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

namespace InAppPurchasingDemo
{
    public sealed partial class MainPage : Page
    {
        private const string PDF_EXPORT_FILTER = "PDFExportFilter";

        public MainPage()
        {
            this.InitializeComponent();
        }
        
        protected override async void OnNavigatedTo(NavigationEventArgs e)
        {
            #if DEBUG
                StorageFolder proxyDataFolder = await Package.Current.InstalledLocation.GetFolderAsync("data");
                StorageFile proxyFile = await proxyDataFolder.GetFileAsync("WindowsStoreProxy.xml");
                CurrentAppSimulator.LicenseInformation.LicenseChanged += this.OnLicenseChanged;
                await CurrentAppSimulator.ReloadSimulatorAsync(proxyFile);
                ListingInformation listing = await CurrentAppSimulator.LoadListingInformationAsync();
            #else
                ListingInformation listing = await CurrentApp.LoadListingInformationAsync();
                CurrentApp.LicenseInformation.LicenseChanged += this.OnLicenseChanged;
            #endif
            var feature = listing.ProductListings[PDF_EXPORT_FILTER];
            this.statusTextBlock.Text = string.Format("Sie können die Funktion \"{0}\" für {1} erwerben.", 
                feature.Name, feature.FormattedPrice);
        }

        private void OnLicenseChanged()
        {
            LicenseInformation licenseInfo = CurrentAppSimulator.LicenseInformation;
            var productLicense = licenseInfo.ProductLicenses[PDF_EXPORT_FILTER];
            if (productLicense.IsActive)
            {
                this.statusTextBlock.Text = "Die Funktion kann verwendet werden.";
            }
            else
            {
                this.statusTextBlock.Text = "Sie müssen diese Funktion erst erwerben um sie verwenden zu können.";
            }
        }

        private void testLicenseButton_Click(object sender, RoutedEventArgs e)
        {
            this.OnLicenseChanged();
        }

        private async void buyLicenseButton_Click(object sender, RoutedEventArgs e)
        {
            LicenseInformation licenseInfo = CurrentAppSimulator.LicenseInformation;
            ProductLicense productLicense = licenseInfo.ProductLicenses["PDFExportFilter"];

            if (!productLicense.IsActive)
            {
                var longdateTemplate = new DateTimeFormatter("shortdate");
                var message = Environment.NewLine + "Das Feature läuft ab am: " +
                    longdateTemplate.Format(productLicense.ExpirationDate);
                int remainingDays = (productLicense.ExpirationDate - DateTime.Now).Days;
                message += string.Format(", {0} Tagen verbleibend.", remainingDays);

                this.statusTextBlock.Text = "Kaufvorgang läuft...";
                try
                {
                    string receipt = await CurrentAppSimulator.RequestProductPurchaseAsync(PDF_EXPORT_FILTER, false);
                    productLicense = licenseInfo.ProductLicenses[PDF_EXPORT_FILTER];
                    if (productLicense.IsActive)
                    {
                        this.statusTextBlock.Text = "Sie haben das Feature erworben." + message;
                    }
                }
                catch (Exception)
                {
                    this.statusTextBlock.Text = "Feature konnte auf Grund eines Fehlers nicht erworben werden.";
                }
            }
            else
            {
                this.statusTextBlock.Text = "Sie haben das Feature bereits erworben.";
            }
        }
    }
}
