﻿using System;
using System.Threading.Tasks;
using Windows.ApplicationModel;
using Windows.ApplicationModel.Store;
using Windows.Globalization.DateTimeFormatting;
using Windows.Storage;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

namespace TrialAppDemo
{
    public sealed partial class MainPage : Page
    {
        public MainPage()
        {
            this.InitializeComponent();
        }

        protected override async void OnNavigatedTo(NavigationEventArgs e)
        {
            #if DEBUG
                StorageFolder proxyDataFolder = await Package.Current.InstalledLocation.GetFolderAsync("data");
                StorageFile proxyFile = await proxyDataFolder.GetFileAsync("WindowsStoreProxy.xml");
                CurrentAppSimulator.LicenseInformation.LicenseChanged += this.TestLicenseStatus;
                await CurrentAppSimulator.ReloadSimulatorAsync(proxyFile);
            #else
                CurrentApp.LicenseInformation.LicenseChanged += this.TestLicenseStatus;
            #endif
        }

        private async void TestLicenseStatus()
        {
            #if DEBUG
                LicenseInformation license = CurrentAppSimulator.LicenseInformation;
                ListingInformation listing = await CurrentAppSimulator.LoadListingInformationAsync();
            #else
                LicenseInformation license = CurrentApp.LicenseInformation;
                ListingInformation listing = await CurrentApp.LoadListingInformationAsync();
            #endif

            var message = "";
            if (license.IsActive)
            {
                if (license.IsTrial)
                {
                    message = string.Format("Die ist eine Testversion. Sie können die Vollversion für {0} erwerben.",
                        listing.FormattedPrice);
                    var dateFormat = new DateTimeFormatter("shortdate");
                    message += string.Format(Environment.NewLine + "Die Trial-Periode läuft ab am: {0}", 
                        dateFormat.Format(license.ExpirationDate));
                    var remainingDays = (license.ExpirationDate - DateTime.Now).Days;
                    message += string.Format(", {0} Tagen verbleibend.", remainingDays);
                }
                else
                {
                    message = "Dies ist eine Vollversion.";
                }
            }
            else
            {
                message = string.Format("Die Testversion ist abgelaufen. Sie können die Vollversion für {0} erwerben.",
                    listing.FormattedPrice);
            }
            this.statusTextBlock.Text = message;
        }

        private async void buyLicenseButton_Click(object sender, RoutedEventArgs e)
        {
            #if DEBUG
                LicenseInformation license = CurrentAppSimulator.LicenseInformation;
            #else
                LicenseInformation license = CurrentApp.LicenseInformation;
            #endif

            if (!license.IsActive || license.IsTrial)
            {
                this.statusTextBlock.Text = "Kaufvorgang läuft...";
                try
                {
                    await CurrentAppSimulator.RequestAppPurchaseAsync(false);
                    if (!license.IsTrial && license.IsActive)
                    {
                        this.statusTextBlock.Text = "Sie haben die Vollversion erworben.";
                    }
                }
                catch (Exception)
                {
                    this.statusTextBlock.Text = "Die App konnte auf Grund eines Fehlers nicht erworben werden.";
                }
            }
            else
            {
                this.statusTextBlock.Text = "Sie haben bereits eine Vollversion der App erworben.";
            }
        }
    }
}
