﻿using System;
using Windows.ApplicationModel.DataTransfer;
using Windows.ApplicationModel.Search;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

namespace ContractsDemo
{
    public sealed partial class MainPage : Page
    {
        private DataTransferManager _dataTransferManager;
        private SearchPane searchPane;
        public static MainPage Current;
        private string[] _words = { "Charms", "Share", "Search", "Devices", "Settings" };

        public MainPage()
        {
            this.InitializeComponent();
            Current = this;
            
        }

        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            // Diese Seite als "Share"-Source registrieren
            _dataTransferManager = DataTransferManager.GetForCurrentView();
            _dataTransferManager.DataRequested += this.OnDataRequested;
            
            // Diese Seite als "Search"-Target registrieren
            searchPane = SearchPane.GetForCurrentView();
            searchPane.SuggestionsRequested += this.OnSearchPaneSuggestionsRequested;
        }

        protected override void OnNavigatedFrom(NavigationEventArgs e)
        {
            // Diese Seite als "Share"-Source abmelden
            _dataTransferManager.DataRequested -= this.OnDataRequested;

            // Diese Seite als "Search"-Target abmelden
            searchPane.SuggestionsRequested -= this.OnSearchPaneSuggestionsRequested;
        }

        private void OnDataRequested(DataTransferManager sender, DataRequestedEventArgs e)
        {
            var dataPackageTitle = "Titel";
            var dataPackageText = "Inhalt";
            var dataPackageDescription = "Beschreibung";

            // Der Titel muss zwingend angegeben werden
            if (!string.IsNullOrEmpty(dataPackageTitle))
            {
                if (!string.IsNullOrEmpty(dataPackageText))
                {
                    DataPackage requestData = e.Request.Data;
                    requestData.Properties.Title = dataPackageTitle;

                    // Der Beschreibungstext ist optional
                    if (dataPackageDescription != null)
                    {
                        requestData.Properties.Description = dataPackageDescription;
                    }
                    requestData.SetText(dataPackageText);
                }
                else
                {
                    e.Request.FailWithDisplayText("Geben Sie einen Text ein, den Sie teilen möchten.");
                }
            }
            else
            {
                e.Request.FailWithDisplayText("Es wurde kein Titel angegeben!");
            }
        }

        private void OnSearchPaneSuggestionsRequested(SearchPane sender, SearchPaneSuggestionsRequestedEventArgs e)
        {
            var queryText = e.QueryText;

            var request = e.Request;
            foreach (string word in _words)
            {
                if (word.StartsWith(queryText, StringComparison.CurrentCultureIgnoreCase))
                {
                    // Treffer im Suchbereich anzeigen
                    request.SearchSuggestionCollection.AppendQuerySuggestion(word);

                    // Bei max. 5 Ergebnissen abbrechen
                    if (request.SearchSuggestionCollection.Size >= 5)
                        break;
                }
            }
            this.DataContext = queryText;
        }

        private void shareButton_Click(object sender, RoutedEventArgs e)
        {
            DataTransferManager.ShowShareUI();
        }

        private void searchButton_Click(object sender, RoutedEventArgs e)
        {
            SearchPane.GetForCurrentView().Show();
        }

    }
}
