﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Runtime.Serialization;
using System.Threading.Tasks;
using Windows.ApplicationModel;
using Windows.ApplicationModel.Activation;
using Windows.Storage;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace NavigationDemo
{
    sealed partial class App : Application
    {
        private const string NAVIGATION_STATE_FILENAME = "NavigationState.xml";
        
        public App()
        {
            this.InitializeComponent();
            this.Suspending += OnSuspending;
        }

        protected override async void OnLaunched(LaunchActivatedEventArgs args)
        {
            Frame rootFrame = Window.Current.Content as Frame;
            if (rootFrame == null)
            {
                rootFrame = new Frame();
                if (args.PreviousExecutionState == ApplicationExecutionState.Terminated)
                {
                    await RestoreAsync(rootFrame);
                }
                Window.Current.Content = rootFrame;
            }

            if (rootFrame.Content == null)
            {
                if (!rootFrame.Navigate(typeof(MainPage), args.Arguments))
                {
                    throw new Exception("Failed to create initial page");
                }
            }
            Window.Current.Activate();
        }

        private async void OnSuspending(object sender, SuspendingEventArgs e)
        {
            var deferral = e.SuspendingOperation.GetDeferral();
            var frame = Window.Current.Content as Frame;
            await SaveAsync(frame);
            deferral.Complete();
        }

        private static async Task SaveAsync(Frame sourceFrame)
        {
            var state = sourceFrame.GetNavigationState();
            var dataStream = new MemoryStream();
            var serializer = new DataContractSerializer(typeof(string));
            serializer.WriteObject(dataStream, state);
            var file = await ApplicationData.Current.LocalFolder.CreateFileAsync(NAVIGATION_STATE_FILENAME, CreationCollisionOption.ReplaceExisting);
            using (Stream fileStream = await file.OpenStreamForWriteAsync())
            {
                dataStream.Seek(0, SeekOrigin.Begin);
                await dataStream.CopyToAsync(fileStream);
                await fileStream.FlushAsync();
            }
        }

        private static async Task RestoreAsync(Frame targetFrame)
        {
            var state = "";
            var file = await ApplicationData.Current.LocalFolder.GetFileAsync(NAVIGATION_STATE_FILENAME);
            using (var inStream = await file.OpenSequentialReadAsync())
            {
                var serializer = new DataContractSerializer(typeof(string));
                state = serializer.ReadObject(inStream.AsStreamForRead()) as string;
            }
            targetFrame.SetNavigationState(state);
        }
    }
}
