﻿using System;
using Windows.ApplicationModel;
using Windows.ApplicationModel.Activation;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace WindowDemo
{
    sealed partial class App : Application
    {
        public App()
        {
            // Unhandled Exception Handler registrieren
            this.UnhandledException += App_UnhandledException;

            this.InitializeComponent();
            this.Suspending += OnSuspending;
        }

        private async void App_UnhandledException(object sender, UnhandledExceptionEventArgs e)
        {
            e.Handled = true; // Herunterfahren der App verhindern
            await new MessageDialog("Ein interner Fehler ist aufgetreten.\n\nFehlernummer: " + e.Exception.HResult.ToString()).ShowAsync();
        }

        protected override void OnLaunched(LaunchActivatedEventArgs args)
        {
            Frame rootFrame = Window.Current.Content as Frame;
            if (rootFrame == null)
            {
                rootFrame = new Frame();
                if (args.PreviousExecutionState == ApplicationExecutionState.Terminated)
                {
                    //TODO: Load state from previously suspended application
                }
                Window.Current.Content = rootFrame;
            }

            if (rootFrame.Content == null)
            {
                if (!rootFrame.Navigate(typeof(MainPage), args.Arguments))
                {
                    throw new Exception("Failed to create initial page");
                }
            }
            MainPage.Current.OutputMessage("Window.Visible: " + Window.Current.Visible.ToString());
            MainPage.Current.OutputMessage("Window.Bounds: " + Window.Current.Bounds.ToString());
            MainPage.Current.OutputMessage("Window.Core.FlowDirection: " + Window.Current.CoreWindow.FlowDirection.ToString());
            MainPage.Current.OutputMessage("Window.Core.IsInputEnabled: " + Window.Current.CoreWindow.IsInputEnabled.ToString());
            MainPage.Current.OutputMessage("Window.Core.PointerCursor: " + Window.Current.CoreWindow.PointerCursor.Type.ToString());
            MainPage.Current.OutputMessage("Window.Core.PointerPosition: " + Window.Current.CoreWindow.PointerPosition.ToString());
            MainPage.Current.OutputMessage("\n----------------------------------------------------------------------------------------\n");
            Window.Current.Activated += (s, e) => MainPage.Current.OutputMessage("Window: Activated");
            Window.Current.SizeChanged += (s, e) => MainPage.Current.OutputMessage("Window: SizeChanged");
            Window.Current.VisibilityChanged += (s, e) => MainPage.Current.OutputMessage("Window: VisibilityChanged");
            Window.Current.CoreWindow.CharacterReceived += (s, e) => MainPage.Current.OutputMessage("CoreWindow: CharacterReceived");
            Window.Current.CoreWindow.InputEnabled += (s, e) => MainPage.Current.OutputMessage("CoreWindow: InputEnabled");
            Window.Current.CoreWindow.KeyDown += (s, e) => MainPage.Current.OutputMessage("CoreWindow: KeyDown");
            Window.Current.CoreWindow.KeyUp += (s, e) => MainPage.Current.OutputMessage("CoreWindow: KeyUp");
            Window.Current.CoreWindow.PointerEntered += (s, e) => MainPage.Current.OutputMessage("CoreWindow: PointerEntered");
            Window.Current.CoreWindow.PointerExited += (s, e) => MainPage.Current.OutputMessage("CoreWindow: PointerExited");
            //Window.Current.CoreWindow.PointerMoved += (s, e) => MainPage.Current.OutputMessage("CoreWindow: PointerMoved");
            Window.Current.CoreWindow.PointerPressed += (s, e) => MainPage.Current.OutputMessage("CoreWindow: PointerPressed");
            Window.Current.CoreWindow.PointerReleased += (s, e) => MainPage.Current.OutputMessage("CoreWindow: PointerReleased");
            Window.Current.CoreWindow.PointerWheelChanged += (s, e) => MainPage.Current.OutputMessage("CoreWindow: PointerWheelChanged");
            Window.Current.CoreWindow.TouchHitTesting += (s, e) => MainPage.Current.OutputMessage("CoreWindow: TouchHitTesting");
            
            Window.Current.Activate();
        }

        private void OnSuspending(object sender, SuspendingEventArgs e)
        {
            var deferral = e.SuspendingOperation.GetDeferral();
            //TODO: Save application state and stop any background activity
            deferral.Complete();
        }
    }
}
