﻿using System;
using Windows.ApplicationModel.DataTransfer;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Navigation;

namespace ListViewDragDropDemo
{
    public sealed partial class MainPage : Page
    {
        private ListViewDragDropDemo.DataStore _store;

        public MainPage()
        {
            this.InitializeComponent();
            _store = new DataStore();
            this.sourceListView.ItemsSource = _store.GetItems();
        }

        private void sourceListView_DragItemsStarting(object sender, DragItemsStartingEventArgs e)
        {
            var id = ((Fruit)e.Items[0]).Id;
            e.Data.RequestedOperation = DataPackageOperation.Copy;
            e.Data.SetDataProvider("Fruit", request => request.SetData(id));
        }

        private async void destinationListView_Drop(object sender, DragEventArgs e)
        {
            var listView = sender as ListView;
            if (e.Data.RequestedOperation == DataPackageOperation.Copy)
            {
                var id = (int)await e.Data.GetView().GetDataAsync("Fruit");
                var fruit = _store.GetItemById(id);
                listView.Items.Add(fruit);
            }
        }

        private async void destinationListView_DragOver(object sender, DragEventArgs e)
        {
            var listView = sender as ListView;
            var id = (int)await e.Data.GetView().GetDataAsync("Fruit");
            foreach (var item in listView.Items)
            {
                var fruit = item as Fruit;
                if (fruit.Id == id)
                {
                    e.Data.RequestedOperation = DataPackageOperation.None;
                }
            }
        }
    }
}
