﻿using System.Collections.ObjectModel;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Navigation;

namespace CollectionViewDemo
{
    public sealed partial class MainPage : Page
    {
        private ICollectionView _view;

        public MainPage()
        {
            this.InitializeComponent();

            var list = new ObservableCollection<Person>()
            {
              new Person { FirstName = "Bob", LastName = "Stevens", Gender = Gender.Male },
              new Person { FirstName = "Bill", LastName = "Winding", Gender = Gender.Male },
              new Person { FirstName = "Mary", LastName = "Holden", Gender = Gender.Female },
              new Person { FirstName = "Ann", LastName = "Friedman", Gender = Gender.Female }
            };
            _view = new CollectionViewSource() { Source = list }.View;
            this.DataContext = _view;
        }

        private void moveFirstButton_Click(object sender, RoutedEventArgs e)
        {
            _view.MoveCurrentToFirst();
        }

        private void movePreviousButton_Click(object sender, RoutedEventArgs e)
        {
            if (_view.CurrentPosition > 0)
                _view.MoveCurrentToPrevious();
        }

        private void moveNextButton_Click(object sender, RoutedEventArgs e)
        {
            if (_view.CurrentPosition < _view.Count-1)
                _view.MoveCurrentToNext();
        }

        private void moveLastButton_Click(object sender, RoutedEventArgs e)
        {
            _view.MoveCurrentToLast();
        }

        private void positionTextBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            int pos;
            if (int.TryParse(((TextBox)sender).Text, out pos))
            {
                if (pos >=0 && pos < _view.Count)
                    _view.MoveCurrentToPosition(pos);
            }
        }
    }
}
